#        ________________________
#        |\                      \
#        | \ _____________________\
#        |  |                      |
#        |  |       |\     |       |
#        |  |       | \    |       |
#        |  |       |  \   |       |
#        |  |       |   \  |       |
#        \  |       |    \ |       |
#         \ |       |     \|       |
#          \|______________________|

__version__ = "0.0.2"

"""
################# notionpy library ####################


-> notionpy is a python library made for simplifying interaction with notion for developers 
to be able to integrate notion with your programme easily 

-> Basic usage :
        >>> Creating page \ database
                NotionClient.create.page\db
        >>> Querying page \ database
                NotionClient.query.page\db
        >>> Updating page 
                NotionClient.update.page

-> Supported properties :
        -title          -rich_text
        -select         -multi_select
        -relation       -people
        -checkbox       -url
        -files          -email
        -phone          -number

::copyright: (c) 2022 by Kareem Ebrahim.:

"""
